@@ -20,10 +20,10 @@ using namespace KPIM;
 
 /// Class KCheckComboBox::Private
 
-namespace KPIM {
+namespace KPIM
+{
 class Q_DECL_HIDDEN KCheckComboBox::Private
 {
-
 public:
     Private(KCheckComboBox *qq)
         : mSeparator(QLatin1Char(','))
@@ -42,6 +42,7 @@ public:
     bool mSqueezeText = false;
     bool mIgnoreHide = false;
     bool mAlwaysShowDefaultText = false;
+
 private:
     KCheckComboBox *const q;
 };
@@ -49,8 +50,8 @@ private:
 
 void KCheckComboBox::Private::makeInsertedItemsCheckable(const QModelIndex &parent, int start, int end)
 {
-    Q_UNUSED(parent);
-    auto *model = qobject_cast<QStandardItemModel *>(q->model());
+    Q_UNUSED(parent)
+    auto model = qobject_cast<QStandardItemModel *>(q->model());
     if (model) {
         for (int r = start; r <= end; ++r) {
             QStandardItem *item = model->item(r, 0);
@@ -80,8 +81,8 @@ QString KCheckComboBox::Private::squeeze(const QString &text)
 
 void KCheckComboBox::Private::updateCheckedItems(const QModelIndex &topLeft, const QModelIndex &bottomRight, int role)
 {
-    Q_UNUSED(topLeft);
-    Q_UNUSED(bottomRight);
+    Q_UNUSED(topLeft)
+    Q_UNUSED(bottomRight)
 
     const QStringList items = q->checkedItems(role);
     QString text;
@@ -107,8 +108,7 @@ void KCheckComboBox::Private::toggleCheckState()
         QVariant value = index.data(Qt::CheckStateRole);
         if (value.isValid()) {
             auto state = static_cast<Qt::CheckState>(value.toInt());
-            q->model()->setData(index, state == Qt::Unchecked ? Qt::Checked : Qt::Unchecked,
-                                Qt::CheckStateRole);
+            q->model()->setData(index, state == Qt::Unchecked ? Qt::Checked : Qt::Unchecked, Qt::CheckStateRole);
         }
     }
 }
@@ -122,8 +122,7 @@ KCheckComboBox::KCheckComboBox(QWidget *parent)
     connect(this, qOverload<int>(&QComboBox::activated), this, [this]() {
         d->toggleCheckState();
     });
-    connect(model(), &QAbstractItemModel::rowsInserted, this,
-            [this](const QModelIndex &index, int start, int end) {
+    connect(model(), &QAbstractItemModel::rowsInserted, this, [this](const QModelIndex &index, int start, int end) {
         d->makeInsertedItemsCheckable(index, start, end);
     });
     connect(model(), &QAbstractItemModel::dataChanged, this, [this](const QModelIndex &topLeft, const QModelIndex &bottomRight) {
@@ -136,7 +135,7 @@ KCheckComboBox::KCheckComboBox(QWidget *parent)
     lineEdit()->setAlignment(Qt::AlignLeft);
     connect(lineEdit(), &QLineEdit::textChanged, this, [this](const QString &text) {
         if (text.isEmpty()) {
-            //Clear checked items
+            // Clear checked items
             setCheckedItems(QStringList());
         }
     });
@@ -177,8 +176,7 @@ QStringList KCheckComboBox::checkedItems(int role) const
     QStringList items;
     if (model()) {
         const QModelIndex index = model()->index(0, modelColumn(), rootModelIndex());
-        const QModelIndexList indexes = model()->match(index, Qt::CheckStateRole,
-                                                       Qt::Checked, -1, Qt::MatchExactly);
+        const QModelIndexList indexes = model()->match(index, Qt::CheckStateRole, Qt::Checked, -1, Qt::MatchExactly);
         items.reserve(indexes.count());
         for (const QModelIndex &index : indexes) {
             items += index.data(role).toString();
@@ -229,7 +227,7 @@ bool KCheckComboBox::itemEnabled(int index)
 {
     Q_ASSERT(index >= 0 && index <= count());
 
-    auto *itemModel = qobject_cast<QStandardItemModel *>(model());
+    auto itemModel = qobject_cast<QStandardItemModel *>(model());
     Q_ASSERT(itemModel);
 
     QStandardItem *item = itemModel->item(index, 0);
@@ -240,7 +238,7 @@ void KCheckComboBox::setItemEnabled(int index, bool enabled)
 {
     Q_ASSERT(index >= 0 && index <= count());
 
-    auto *itemModel = qobject_cast<QStandardItemModel *>(model());
+    auto itemModel = qobject_cast<QStandardItemModel *>(model());
     Q_ASSERT(itemModel);
 
     QStandardItem *item = itemModel->item(index, 0);
